@@ -15,7 +15,7 @@ pub(crate) mod writer;
 pub use rand;
 
 /// Current file spec version, both `Loader` and `Builder`
-pub const VERSION: u16 = 15;
+pub const VERSION: u16 = 16;
 
 /// Size of a keypair: (secret + public)
 pub const KEYPAIR_LENGTH: usize = 64;
@@ -46,7 +46,7 @@ pub mod prelude {
 		builder::{Builder, BuilderConfig},
 		leaf::{Leaf, CompressMode},
 	};
-	pub use ed25519_dalek::{Keypair, PublicKey};
+	pub use ed25519_dalek::{Keypair, PublicKey, SecretKey};
 }
 
 /// Some utility functions to keep you happy
