@@ -9,8 +9,8 @@ pub fn gen_keypair() -> esdalek::Keypair {
 	esdalek::Keypair::generate(&mut OsRng)
 }
 
-/// Use this to read and parse a `Keypair` from a `io::Read` handle
-pub fn read_keypair<R: Read>(mut handle: R) -> anyhow::Result<esdalek::Keypair> {
+// Use this to read and parse a `Keypair` from a `io::Read` handle
+pub(crate) fn read_keypair<R: Read>(mut handle: R) -> anyhow::Result<esdalek::Keypair> {
 	let mut keypair_bytes = [0; crate::KEYPAIR_LENGTH];
 	handle.read_exact(&mut keypair_bytes)?;
 	Ok(esdalek::Keypair::from_bytes(&keypair_bytes)?)
